using System;
using System.IO;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.Net;
using WindowsLive.Writer.Api;


namespace InsertFileViaFtp
{
    public partial class UploadForm : Form
    {
        public string linkUrl = string.Empty;
        public string displayText = string.Empty;

        public UploadForm()
        {
            InitializeComponent();

            // load in the FTP servers from the App.config file
            LoadFTPSites();
        }

        private void LoadFTPSites()
        {
            string xmlFilename = AppDomain.CurrentDomain.BaseDirectory + @"Plugins\InsertFileViaFtp.dll.xml";
            if (File.Exists(xmlFilename))
            {
                XmlDocument xmlDoc = new XmlDocument();
                xmlDoc.Load(xmlFilename);
                foreach (XmlNode node in xmlDoc.SelectNodes(@"/ftpservers/*"))
                {
                    try
                    {
                        FTPSite obj = new FTPSite(node);
                        cboFTPServer.Items.Add(obj);
                        if (obj.IsDefault)
                            cboFTPServer.SelectedItem = obj;
                    }
                    catch (NullReferenceException exNR)
                    {
                        MessageBox.Show("The XML file looks invalid, please correct before proceeding.", "InsertFileViaFtp", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show("Error : " + ex.Message, "InsertFileViaFtp", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                }
            }
            else
            {
                MessageBox.Show("Could not find the XML file to get FTP info from.", "InsertFileViaFtp", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btnBrowseForFile_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                txtFilename.Text = openFileDialog1.FileName;
                SetDisplayText();
            }
        }

        private void SetDisplayText()
        {
            if (txtFilename.Text.Length > 0)
            {
                try
                {
                    FTPSite ftpSite = (FTPSite)cboFTPServer.SelectedItem;
                    txtDisplayText.Text = ftpSite.LinkUrl + (new FileInfo(txtFilename.Text)).Name;
                }
                catch
                {
                    // do nothing
                }
            }
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            if (File.Exists(txtFilename.Text))
            {
                // ftp upload the file
                string fileName = txtFilename.Text;
                try
                {
                    FTPSite ftpSite = (FTPSite)cboFTPServer.SelectedItem;
                    string fileUrl = ftpSite.ServerUri + HtmlServices.HtmlEncode(new FileInfo(fileName).Name);
                    if (ftpSite.Debug)
                        MessageBox.Show("Uploading file to " + fileUrl, "InsertFileViaFtp", MessageBoxButtons.OK, MessageBoxIcon.Information);
                    using (WebClient client = new WebClient())
                    {
                        try
                        {
                            client.Credentials = new System.Net.NetworkCredential(ftpSite.Username, ftpSite.Password);
                            client.UploadFile(fileUrl, "STOR", fileName);
                            linkUrl = ftpSite.LinkUrl + new FileInfo(fileName).Name;
                            displayText = txtDisplayText.Text;
                        }
                        catch (Exception ex)
                        {
                            string message = string.Format("Error : {0}\r\n\r\nUpload to : {1}\r\n\r\nUpload from : {2}", ex.Message, fileUrl, fileName);
                            MessageBox.Show(message, "InsertFileViaFtp", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        }
                    }
                }
                catch (NullReferenceException exNR)
                {
                    MessageBox.Show("The XML file looks invalid, please correct before proceeding.", "InsertFileViaFtp", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
            else
            {
                if (txtFilename.Text.Length > 0)
                    MessageBox.Show("Could not find file : " + txtFilename.Text,"InsertFileViaFtp",MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            }
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {

        }

        private void cboFTPServer_SelectedIndexChanged(object sender, EventArgs e)
        {
            SetDisplayText();
        }


    }
}